@@ -6,7 +6,7 @@ use 5.016;
 use warnings;
 use utf8;
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 use parent qw(CPANPLUS::Dist::Debora::Package);
 
@@ -358,6 +358,9 @@ if ($package->is_noarch) {
     $OUT .= "AutoReq:   0\n";
 }
 else {
+    if (@{$package->shared_objects} == 0) {
+        $OUT .= "%global debug_package %{nil}\n";
+    }
     $OUT .= "%global __perl_requires /bin/true\n";
     $OUT .= "%global __perllib_requires /bin/true\n";
     $OUT .= "%global __perltest_requires /bin/true\n";
@@ -537,7 +540,7 @@ CPANPLUS::Dist::Debora::Package::RPM - Create binary RPM packages
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
